FocusedMenuItem class

Constructors

FocusedMenuItem({required Widget title, Color? backgroundColor, Icon? leadingIcon, Icon? trailingIcon, VoidCallback? onPressed, bool? isDefaultAction = false})

Properties

backgroundColor ↔ Color?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDefaultAction ↔ bool?
getter/setter pair
leadingIcon ↔ Icon?
getter/setter pair
onPressed ↔ VoidCallback?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ Widget
getter/setter pair
trailingIcon ↔ Icon?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited